@@ -57,7 +57,10 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <math.h>
 
 #include <Imlib2.h>
-#include <giblib/giblib.h>
+#include "gib_hash.h"
+#include "gib_imlib.h"
+#include "gib_list.h"
+#include "gib_style.h"
 
 #include "structs.h"
 #include "menu.h"
@@ -102,7 +105,7 @@ enum slide_change { SLIDE_NEXT, SLIDE_PREV, SLIDE_RAND, SLIDE_FIRST, SLIDE_LAST,
 	SLIDE_JUMP_BACK
 };
 
-enum image_bg { IMAGE_BG_CHECKS = 0, IMAGE_BG_BLACK, IMAGE_BG_WHITE };
+enum image_bg { IMAGE_BG_CHECKS = 1, IMAGE_BG_BLACK, IMAGE_BG_WHITE };
 
 #define INPLACE_EDIT_FLIP   -1
 #define INPLACE_EDIT_MIRROR -2
@@ -132,18 +135,18 @@ int feh_load_image(Imlib_Image * im, feh_file * file);
 void show_mini_usage(void);
 void slideshow_change_image(winwidget winwid, int change, int render);
 void slideshow_pause_toggle(winwidget w);
-char *slideshow_create_name(feh_file * file);
+char *slideshow_create_name(feh_file * file, winwidget winwid);
 void init_keyevents(void);
 void init_buttonbindings(void);
 void feh_event_handle_keypress(XEvent * ev);
 void feh_action_run(feh_file * file, char *action);
-char *feh_printf(char *str, feh_file * file);
+char *format_size(int size);
+char *feh_printf(char *str, feh_file * file, winwidget winwid);
 void im_weprintf(winwidget w, char *fmt, ...);
 void feh_draw_zoom(winwidget w);
 void feh_draw_checks(winwidget win);
 void cb_slide_timer(void *data);
 void cb_reload_timer(void *data);
-char *feh_http_load_image(char *url);
 int feh_load_image_char(Imlib_Image * im, char *filename);
 void feh_draw_filename(winwidget w);
 #ifdef HAVE_LIBEXIF
@@ -157,7 +160,10 @@ void feh_display_status(char stat);
 void real_loadables_mode(int loadable);
 void feh_reload_image(winwidget w, int resize, int force_new);
 void feh_filelist_image_remove(winwidget winwid, char do_delete);
+void feh_imlib_print_load_error(char *file, winwidget w, Imlib_Load_Error err);
 void slideshow_save_image(winwidget win);
+void ungib_imlib_save_image_with_error_return(Imlib_Image im, char *file,
+	Imlib_Load_Error * error_return);
 void feh_edit_inplace(winwidget w, int orientation);
 void feh_edit_inplace_lossless(winwidget w, int orientation);
 gib_list *feh_wrap_string(char *text, int wrap_width, Imlib_Font fn, gib_style * style);
@@ -188,4 +194,7 @@ extern feh_menu *menu_main;
 extern feh_menu *menu_close;
 extern char *mode;		/* label for the current mode */
 
+/* to terminate long-running children with SIGALRM */
+extern int childpid;
+
 #endif
