@@ -211,10 +211,7 @@ void add_file_to_filelist_recursively(char *origpath, unsigned char level)
 		if (path[len - 1] == '/')
 			path[len - 1] = '\0';
 
-		if ((!strncmp(path, "http://", 7))
-				|| (!strncmp(path, "https://", 8))
-				|| (!strncmp(path, "ftp://", 6))) {
-			/* Its a url */
+		if (path_is_url(path)) {
 			D(("Adding url %s to filelist\n", path));
 			filelist = gib_list_add_front(filelist, feh_file_new(path));
 			/* We'll download it later... */
@@ -262,27 +259,27 @@ void add_file_to_filelist_recursively(char *origpath, unsigned char level)
 			default:
 				weprintf("Failed to scan directory %s:", path);
 			}
-		}
+		} else {
+			for (cnt = 0; cnt < n; cnt++) {
+				if (strcmp(de[cnt]->d_name, ".")
+						&& strcmp(de[cnt]->d_name, "..")) {
+					char *newfile;
 
-		for (cnt = 0; cnt < n; cnt++) {
-			if (strcmp(de[cnt]->d_name, ".")
-					&& strcmp(de[cnt]->d_name, "..")) {
-				char *newfile;
+					newfile = estrjoin("", path, "/", de[cnt]->d_name, NULL);
 
-				newfile = estrjoin("", path, "/", de[cnt]->d_name, NULL);
+					/* This ensures we go down one level even if not fully recursive
+					   - this way "feh some_dir" expands to some_dir's contents */
+					if (opt.recursive)
+						add_file_to_filelist_recursively(newfile, FILELIST_CONTINUE);
+					else
+						add_file_to_filelist_recursively(newfile, FILELIST_LAST);
 
-				/* This ensures we go down one level even if not fully recursive
-				   - this way "feh some_dir" expands to some_dir's contents */
-				if (opt.recursive)
-					add_file_to_filelist_recursively(newfile, FILELIST_CONTINUE);
-				else
-					add_file_to_filelist_recursively(newfile, FILELIST_LAST);
-
-				free(newfile);
+					free(newfile);
+				}
+				free(de[cnt]);
 			}
-			free(de[cnt]);
+			free(de);
 		}
-		free(de);
 		closedir(dir);
 	} else if (S_ISREG(st.st_mode)) {
 		D(("Adding regular file %s to filelist\n", path));
@@ -576,7 +573,7 @@ char *feh_absolute_path(char *path)
 
 	if (!path)
 		return(NULL);
-	if (path[0] == '/')
+	if (path[0] == '/' || path_is_url(path))
 		return(estrdup(path));
 	/* This path is not relative. We're gonna convert it, so that a
 	   filelist file can be saved anywhere and feh will still find the
