@@ -162,14 +162,14 @@ void ungib_imlib_save_image_with_error_return(Imlib_Image im, char *file,
 	tmp = strrchr(file, '.');
 	if (tmp) {
 		char *p, *pp;
-		p = gib_estrdup(tmp + 1);
+		p = estrdup(tmp + 1);
 		pp = p;
 		while(*pp) {
 			*pp = tolower(*pp);
 			pp++;
 		}
 		imlib_image_set_format(p);
-		gib_efree(p);
+		free(p);
 	}
 	imlib_save_image_with_error_return(file, error_return);
 }
@@ -242,9 +242,7 @@ int feh_load_image(Imlib_Image * im, feh_file * file)
 	if (!file || !file->filename)
 		return 0;
 
-	/* Handle URLs */
-	if ((!strncmp(file->filename, "http://", 7)) || (!strncmp(file->filename, "https://", 8))
-			|| (!strncmp(file->filename, "ftp://", 6))) {
+	if (path_is_url(file->filename)) {
 		image_source = SRC_HTTP;
 
 		if ((tmpname = feh_http_load_image(file->filename)) == NULL)
@@ -960,7 +958,6 @@ void feh_draw_caption(winwidget w)
 	feh_imlib_image_fill_text_bg(im, tw, th);
 
 	l = lines;
-	x = 0;
 	y = 0;
 	while (l) {
 		p = (char *) l->data;
@@ -1155,7 +1152,6 @@ gib_list *feh_wrap_string(char *text, int wrap_width, Imlib_Font fn, gib_style *
 						list = gib_list_add_end(list, estrdup(line));
 						free(line);
 						line = NULL;
-						line_width = 0;
 					}
 					gib_list_free_and_data(words);
 				}
