@@ -39,7 +39,7 @@ void init_slideshow_mode(void)
 	gib_list *l = filelist, *last = NULL;
 	feh_file *file = NULL;
 
-	for (l = filelist; l && opt.start_list_at; l = l->next) {
+	for (; l && opt.start_list_at; l = l->next) {
 		if (!strcmp(opt.start_list_at, FEH_FILE(l->data)->filename)) {
 			opt.start_list_at = NULL;
 			break;
@@ -584,7 +584,8 @@ char *feh_printf(char *str, feh_file * file, winwidget winwid)
 				break;
 			default:
 				weprintf("Unrecognized format specifier %%%c", *c);
-				strncat(ret, c - 1, 2);
+				if ((strlen(ret) + 3) < sizeof(ret))
+					strncat(ret, c - 1, 2);
 				break;
 			}
 		} else if ((*c == '\\') && (*(c+1) != '\0') && ((strlen(ret) + 3) < sizeof(ret))) {
@@ -692,7 +693,13 @@ gib_list *feh_list_jump(gib_list * root, gib_list * l, int direction, int num)
 				if (opt.cycle_once) {
 					exit(0);
 				}
-				ret = root;
+				if (opt.randomize) {
+					/* Randomize the filename order */
+					filelist = gib_list_randomize(filelist);
+					ret = filelist;
+				} else {
+					ret = root;
+				}
 			}
 		} else {
 			if (ret->prev)
